<?php
if ( ! defined( 'ABSPATH' ) ) { die( '-1' );}

define( 'MHC_ADMIN_DIR', trailingslashit( dirname( __FILE__ ) ) );
define( 'MHC_ADMIN_URL', trailingslashit( MH_COMPOSER_PLUGIN_URI . '/app/admin/' ) );

/**
 * Defines which App parts to load.
 *
 * It can be different on a per page bases to keep it as performant and lightweight as possible
 * by only loading what is needed.
 */

/**
 * Load App parts.
 *
 * This function loads App parts which are only loaded once, even if they are called many times.
 * Admin parts/functions are automatically wrapped in an is_admin() check.
 *
 * @param string|array $parts Name of the App part(s) to include as and indexed array.
 *
 * @return bool Always return true.
 */
if ( ! function_exists( 'mh_app_load_parts' ) ) :
function mh_app_load_parts( $parts ) {
	static $loaded = array();

	// Load in front end and backend.
	$common = array();

	// Only load admin parts if is_admin() is true.
	$admin = is_admin() ? array(
		'impoexpo' => MHC_ADMIN_DIR . 'impoexpo.php',
		'capture' => MHC_ADMIN_DIR . 'capture.php',
		'cache'       => array(
			MHC_ADMIN_DIR . 'cache.php',
			MHC_ADMIN_DIR . 'class-cache.php'
		),
	) : array();

	// Set dependencies.
	$dependencies = array(
		'impoexpo' => 'cache',
		'capture' => 'cache',
	);

	foreach ( (array) $parts as $part ) {
		// Stop here if the part is already loaded or doesn't exists.
		if ( in_array( $part, $loaded ) || ( ! isset( $common[$part] ) && ! isset( $admin[$part] ) ) ) {
			continue;
		}

		// Cache loaded part before calling dependencies.
		$loaded[] = $part;

		// Load dependencies.
		if ( array_key_exists( $part, $dependencies ) ) {
			mh_app_load_parts( $dependencies[$part] );
		}

		$_parts = array();

		if ( isset( $common[$part] ) ) {
			$_parts = (array) $common[$part];
		}

		if ( isset( $admin[$part] ) ) {
			$_parts = array_merge( (array) $_parts, (array) $admin[$part] );
		}

		foreach ( $_parts as $part_path ) {
			require_once( $part_path );
		}

		/**
		 * Fires when an App part is loaded.
		 *
		 * The dynamic portion of the hook name, $part, refers to the name of the App part loaded.
		 */
		do_action( 'mh_app_loaded_part_' . $part );
	}
}
endif;

function mh_app_request_layout($layout_id){
	$key = trim(get_option( 'mharty_activation_key', '' ));

	$remote_url = add_query_arg( array( 'repositories' => 'layouts', 'get_layout' => 'get' ), 'https://mharty.com/' );
	$remote_request = array( 'timeout' => 20, 'body' => array('key' => $key, 'id' => $layout_id), 'user-agent' => 'WordPress;' . home_url() );
	$raw_response = wp_remote_post( $remote_url, $remote_request );
	
	//@todo add better validation for errors
	if ( !is_wp_error( $raw_response ) && ( $raw_response['response']['code'] == 200 ) ){
		$response =   wp_remote_retrieve_body( $raw_response );
	}else{
		$response = false;
	}
	
	return $response;
}


if ( is_admin() ) {
		require_once( MH_COMPOSER_DIR . 'admin/assets.php' );
		add_action( 'admin_enqueue_scripts', 'mh_app_load_main_styles' );
		add_action( 'customize_controls_enqueue_scripts', 'mh_app_load_main_styles_customizer' );
	}


if ( ! function_exists( 'mh_app_load_main_styles' ) ) :
function mh_app_load_main_styles( $hook ) {
	if ( ! in_array( $hook, array( 'post.php', 'post-new.php' ) ) ) {
		return;
	}

	wp_enqueue_style( 'mh-admin-app' );
}
endif;

if ( ! function_exists( 'mh_app_load_main_styles_customizer' ) ) :
function mh_app_load_main_styles_customizer( ) {
	wp_enqueue_style( 'mh-admin-app' );
}
endif;