<?php
class MHComposer_Row extends MHComposer_Structure_Element {
	function init() {
		$this->name = esc_html__( 'Row', 'mh-composer' );
		$this->slug = 'mhc_row';

		$this->approved_fields = array(
			'background_image',
			'background_color',
			'gradient_background',
			'gradient_style',
			'background_color_second',
			'remove_padding',
      'remove_padding_mobile',
			'top_padding',
			'bottom_padding',
			'module_id',
			'module_class',
			'admin_label',
			'background_image_size',
			'background_image_repeat',
			'background_image_position_x',
			'background_image_position_y',
			'background_image_position_x_custom',
			'background_image_position_y_custom',
      'mobile_2_pr_row',
      'mobile_reverse',
		);
		
		$this->fields_defaults = array(
      'background_color' 	=> array( '', 'append_default' ),
			'gradient_background' 	=> array( 'off' ),
			'gradient_style' 		 => array( 'horizontal' ),
			'remove_padding' 		 => array( 'off' ),
      'remove_padding_mobile' 		 => array( 'off' ),
			'background_image_size'   	=> array( 'cover' ),
			'background_image_repeat'	=> array( 'no-repeat' ),
			'background_image_position_x'	=> array( 'center' ),
			'background_image_position_y'	=> array( 'center' ),
			'background_image_position_x_custom'	=> array( '50' ),
			'background_image_position_y_custom'	=> array( '50' ),
      'mobile_2_pr_row' => array('off'),
      'mobile_reverse' => array('off'),
		);
	}

	function get_fields() {
		$fields = array(
			'background_image' => array(
				'label'              => esc_html__( 'Background Image', 'mh-composer' ),
				'type'               => 'upload',
				'upload_button_text' => esc_attr__( 'Upload an image', 'mh-composer' ),
				'choose_text'        => esc_attr__( 'Choose a Background Image', 'mh-composer' ),
				'update_text'        => esc_attr__( 'Set As Background', 'mh-composer' ),
				'description'        => esc_html__( 'If defined, this image will be used as a background. To remove a background image, simply delete the URL from the settings field.', 'mh-composer' ),
			),
			'gradient_background' => array(
				'label'             => esc_html__( 'Gradient Background', 'mh-composer' ),
				'type'              => 'switch_button',
				'options'           => array(
					'off' => esc_html__( 'No', 'mh-composer' ),
					'on'  => esc_html__( 'Yes', 'mh-composer' ),
				),
				'affects'           => array(
					'#mhc_gradient_style',
					'#mhc_background_color_second',
				),
				'description'       => esc_html__( 'Switch on this option if you want a gradient background colour for this row.', 'mh-composer' ),
			),
			'background_color' => array(
				'label'           => esc_html__( 'Background Colour', 'mh-composer' ),
				'type'            => 'color-alpha',
        'custom_color'	=> true,
				'description'     => esc_html__( 'Define a custom background colour for your component, or leave blank to use the default colour.', 'mh-composer' ),
			),
			'background_color_second' => array(
				'label'           => esc_html__( 'Gradient Colour', 'mh-composer' ),
				'type'            => 'color-alpha',
				'depends_show_if' => 'on',
				'description'     => esc_html__( 'Define a custom gradient colour for your row.', 'mh-composer' ),
			),
			'gradient_style' => array(
				'label'             => esc_html__( 'Gradient Style', 'mh-composer' ),
				'type'              => 'select',
				'options'           => array(
					'horizontal' 		=> esc_html__( 'Horizontal', 'mh-composer' ),
					'vertical'  		  => esc_html__( 'Vertical', 'mh-composer' ),
					'diagonal_top'	  => esc_html__( 'Diagonal Top', 'mh-composer' ),
					'diagonal_bottom'   => esc_html__( 'Diagonal Bottom', 'mh-composer' ),
					'radial'			=> esc_html__( 'Radial', 'mh-composer' ),
				),
				'depends_show_if' => 'on',
				'description'       => esc_html__( 'This controls the style of the gradient colour.', 'mh-composer' ),
			),
      'remove_padding' => array(
				'label'           => esc_html__( 'Remove Paddings', 'mh-composer' ),
				'type'            => 'switch_button',
				'options'         => array(
					'off' => esc_html__( 'No', 'mh-composer' ),
					'on'  => esc_html__( 'Yes', 'mh-composer' ),
				),
				'affects'           => array(
          '#mhc_remove_padding_mobile',
					'#mhc_top_padding',
					'#mhc_bottom_padding',
				),
				'description'       => esc_html__( 'This option will remove all top and bottom paddings for this row.', 'mh-composer' ),
			),
       'remove_padding_mobile' => array(
				'label'           => esc_html__( 'Remove Paddings on Mobile Only', 'mh-composer' ),
				'type'            => 'switch_button',
				'options'         => array(
					'off' => esc_html__( 'No', 'mh-composer' ),
					'on'  => esc_html__( 'Yes', 'mh-composer' ),
				),
			),
			'top_padding' => array(
				'label'           => esc_html__( 'Top Padding (px)', 'mh-composer' ),
				'type'            => 'range',
				'range_settings' => array(
					'min'  => '0',
					'max'  => '200',
					'step' => '1',
				),
				'depends_show_if'   => 'on',
			),
			'bottom_padding' => array(
				'label'           => esc_html__( 'Bottom Padding (px)', 'mh-composer' ),
				'type'            => 'range',
				'range_settings' => array(
					'min'  => '0',
					'max'  => '200',
					'step' => '1',
				),
				'depends_show_if'   => 'on',
			),
			'background_image_size' => array(
				'label'             => esc_html__( 'Background Image Size', 'mh-composer' ),
				'type'              => 'select',
				'options'           => array(
					'cover'		=> esc_html__( 'Cover', 'mh-composer' ),
					'contain'	=> esc_html__( 'Contain', 'mh-composer' ),
					'auto'		=> esc_html__( 'Auto', 'mh-composer' ),
				),
			),
			'background_image_repeat' => array(
				'label'             => esc_html__( 'Background Image Repeat', 'mh-composer' ),
				'type'              => 'select',
				'options'           => array(
					'no-repeat'	=> esc_html__( 'No repeat', 'mh-composer' ),
					'repeat'	=> esc_html__( 'Repeat', 'mh-composer' ),
				),
			),
			'background_image_position_x' => array(
				'label'             => esc_html__( 'Background Image Position Horizontally', 'mh-composer' ),
				'type'              => 'select',
				'options'           => array(
					'center'	=> esc_html__( 'Centre', 'mh-composer' ),
					'right'		=> esc_html__( 'Right', 'mh-composer' ),
					'left'		=> esc_html__( 'Left', 'mh-composer' ),
					'custom'	=> esc_html__( 'Custom', 'mh-composer' ),
				),
				'affects'           => array(
					'#mhc_background_image_position_x_custom',
				),
				
			),
			'background_image_position_x_custom' => array(
				'label'           => esc_html__( 'Background Image Horizontal Position', 'mh-composer' ),
				'type'            => 'range',
				'range_settings' => array(
					'min'  => '0',
					'max'  => '100',
					'step' => '1',
				),
				'depends_show_if'   => 'custom',
			),
			'background_image_position_y' => array(
				'label'             => esc_html__( 'Background Image Position Vertically', 'mh-composer' ),
				'type'              => 'select',
				'options'           => array(
					'center'	=> esc_html__( 'Centre', 'mh-composer' ),
					'top'		=> esc_html__( 'Top', 'mh-composer' ),
					'bottom'	=> esc_html__( 'Bottom', 'mh-composer' ),
					'custom'	=> esc_html__( 'Custom', 'mh-composer' ),
				),
				'affects'           => array(
					'#mhc_background_image_position_y_custom',
				),
			),
			'background_image_position_y_custom' => array(
				'label'           => esc_html__( 'Background Image Vertical Position', 'mh-composer' ),
				'type'            => 'range',
				'range_settings' => array(
					'min'  => '0',
					'max'  => '100',
					'step' => '1',
				),
				'depends_show_if'   => 'custom',
			),
			'disabled_on' => array(
				'label'           => esc_html__( 'Hide on', 'mh-composer' ),
				'type'            => 'multiple_checkboxes',
				'options'         => array(
					'phone'   => esc_html__( 'Mobile', 'mh-composer' ),
					'tablet'  => esc_html__( 'Tablet', 'mh-composer' ),
					'desktop' => esc_html__( 'Desktop', 'mh-composer' ),
				),
				'additional_att'  => 'disable_on',
				'description'     => esc_html__( 'This will hide the component on selected devices.', 'mh-composer' ),
				'tab_slug'        => 'advanced',
			),
      'mobile_2_pr_row' => array(
				'label'             => esc_html__( '2 Columns on Mobile', 'mh-composer' ),
				'type'              => 'switch_button',
				'options'           => array(
					'off' => esc_html__( 'No', 'mh-composer' ),
					'on'  => esc_html__( 'Yes', 'mh-composer' ),
				),
        'tab_slug'        => 'advanced',
        'affects' => array(
          '#mhc_mobile_reverse',
        ),
			),
      'mobile_reverse' => array(
				'label'             => esc_html__( 'Reverse Columns on Mobile', 'mh-composer' ),
				'type'              => 'switch_button',
				'options'           => array(
					'off' => esc_html__( 'No', 'mh-composer' ),
					'on'  => esc_html__( 'Yes', 'mh-composer' ),
				),
        'tab_slug'        => 'advanced',
        'depends_show_if' => 'off',
			),
			'admin_label' => array(
				'label'       => esc_html__( 'Label', 'mh-composer' ),
				'type'        => 'text',
				'description' => esc_html__( 'This will change the label of the row in the composer for easy identification when collapsed.', 'mh-composer' ),
        'tab_slug'        => 'advanced',
			),
			'module_id' => array(
				'label'             => esc_html__( '{CSS ID}', 'mh-composer' ),
				'type'              => 'text',
				'description'       => esc_html__( 'Enter an optional CSS ID. An ID can be used to create custom CSS styling, or to create links to particular sections of your page.', 'mh-composer' ),
				'tab_slug'          => 'advanced',
			),
			'module_class' => array(
				'label'             => esc_html__( '{CSS Class}', 'mh-composer' ),
				'type'              => 'text',
				'description'       => esc_html__( 'Enter optional CSS classes. A CSS class can be used to create custom CSS styling. You can add multiple classes, separated with a space.', 'mh-composer' ),
				'tab_slug'          => 'advanced',
			),
		);

		return $fields;
	}

	function shortcode_callback( $atts, $content, $function_name ) {
		$module_id					= $this->shortcode_atts['module_id'];
		$module_class				= $this->shortcode_atts['module_class'];
		$shared_module				= $this->shortcode_atts['shared_module'];
		$background_image			= $this->shortcode_atts['background_image'];
		$background_color			= $this->shortcode_atts['background_color'];
		$gradient_background		= $this->shortcode_atts['gradient_background'];
		$background_color_second	= $this->shortcode_atts['background_color_second'];
		$gradient_style				= $this->shortcode_atts['gradient_style'];
		$remove_padding				= $this->shortcode_atts['remove_padding'];
    $remove_padding_mobile				= $this->shortcode_atts['remove_padding_mobile'];
		$top_padding				= $this->shortcode_atts['top_padding'];
		$bottom_padding				= $this->shortcode_atts['bottom_padding'];
		$background_image_size		= $this->shortcode_atts['background_image_size'];
		$background_image_repeat	= $this->shortcode_atts['background_image_repeat'];
		$background_image_position_x	= $this->shortcode_atts['background_image_position_x'];
		$background_image_position_y	= $this->shortcode_atts['background_image_position_y'];
		$background_image_position_x_custom	= $this->shortcode_atts['background_image_position_x_custom'];
		$background_image_position_y_custom	= $this->shortcode_atts['background_image_position_y_custom'];
    $mobile_2_pr_row = $this->shortcode_atts['mobile_2_pr_row'];
    $mobile_reverse = $this->shortcode_atts['mobile_reverse'];


		if ( '' !== $shared_module ) {
			$shared_content = mhc_load_shared_module( $shared_module, $function_name );

			if ( '' !== $shared_content ) {
				return do_shortcode( $shared_content );
			}
		}

		$module_class .= ' mhc_row';

		$module_class = MHComposer_Core::add_module_order_class( $module_class, $function_name );

		$inner_content = do_shortcode( mhc_fix_shortcodes( $content ) );
		$module_class .= '' == trim( $inner_content ) ? ' mhc_row_empty' : '';
    $module_class .= 'off' !== $mobile_2_pr_row ? ' mhc_row_2pr' : '';
    $module_class .= 'off' !== $mobile_reverse && 'off' === $mobile_2_pr_row ? ' mhc_mobile_reverse' : '';
		
		if ('off' !== $remove_padding){
			MHComposer_Core::set_style( $function_name, array(
			'selector'    => '%%order_class%%',
			'declaration' => sprintf('padding-top:%1$s !important; padding-bottom:%2$s !important;',
			'' !== $top_padding ? esc_html( mh_composer_process_range_value( $top_padding )) : '0',
			'' !== $bottom_padding ? esc_html( mh_composer_process_range_value( $bottom_padding )) : '0'
			),
      'media_query' => 'off' !== $remove_padding_mobile ? MHComposer_Core::get_media_query( 'max_width_980' ) : 'general'
			) );
		}
		//background image
		if ( '' !== $background_image ) {
			MHComposer_Core::set_style( $function_name, array(
				'selector'    => '%%order_class%%',
				'declaration' => sprintf(
					'background-image:url(%s);',
					esc_url( $background_image )
				),
			) );
			//background image options
			if ('center' !== $background_image_position_x || 'center' !== $background_image_position_y || 'cover' !== $background_image_size || 'no-repeat' !== $background_image_repeat) {
				MHComposer_Core::set_style( $function_name, array(
					'selector'    => '%%order_class%%',
					'declaration' => sprintf(
						'%s%s%s',
						 sprintf('background-position:%1$s %2$s;',
              'custom' !== $background_image_position_x ? esc_html( $background_image_position_x ) : esc_html( $background_image_position_x_custom . '%' ),
              'custom' !== $background_image_position_y ? esc_html( $background_image_position_y ) : esc_html( $background_image_position_y_custom . '%' )
              ),
						'no-repeat' !== $background_image_repeat ? sprintf('background-repeat:%s;', esc_html( $background_image_repeat ) ) : '',
						'cover' !== $background_image_size ? sprintf('background-size:%s;', esc_html( $background_image_size ) ) : ''
					),
				) );
			}
		}
		//background colour
		if ( '' !== $background_color && 'off' === $gradient_background ) {
			MHComposer_Core::set_style( $function_name, array(
				'selector'    => '%%order_class%%',
				'declaration' => sprintf(
					'background-color:%s;',
					esc_html( $background_color )
				),
			) );
		//gradient colour
		}elseif ( 'off' !== $gradient_background  && '' !== $background_color && '' !== $background_color_second) {
			$color1 = esc_html( $background_color );
			$color2 = esc_html( $background_color_second );
			$image = '' !== $background_image ? sprintf('url(%s), ', esc_url( $background_image )) : '';
			if ('horizontal' === $gradient_style){	
				MHComposer_Core::set_style( $function_name, array(
					'selector'    => '%%order_class%%',
					'declaration' => "background: $color1;
					background-image: $image -webkit-linear-gradient(left, $color1 0%,$color2 100%);
					background-image: $image linear-gradient(to right, $color1 0%,$color2 100%);
					filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='$color1', endColorstr='$color2',GradientType=1 );",
				) );
			}

			if ('vertical' === $gradient_style){
				MHComposer_Core::set_style( $function_name, array(
					'selector'    => '%%order_class%%',
					'declaration' => "background: $color1;
					background-image: $image -webkit-linear-gradient(top, $color1 0%,$color2 100%);
					background-image: $image linear-gradient(to bottom, $color1 0%,$color2 100%);
					filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='$color1', endColorstr='$color2',GradientType=0 );",
				) );
			}

			if ('diagonal_top' === $gradient_style){
				MHComposer_Core::set_style( $function_name, array(
					'selector'    => '%%order_class%%',
					'declaration' => "background: $color1;
					background-image: $image -webkit-linear-gradient(-45deg, $color1 0%,$color2 100%);
					background-image: $image linear-gradient(135deg, $color1 0%,$color2 100%);
					filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='$color1', endColorstr='$color2',GradientType=1 );",
				) );
			}

			if ('diagonal_bottom' === $gradient_style){
				MHComposer_Core::set_style( $function_name, array(
					'selector'    => '%%order_class%%',
					'declaration' => "background: $color1; 
					background-image: $image -webkit-linear-gradient(45deg, $color1 0%,$color2 100%);
					background-image: $image linear-gradient(45deg, $color1 0%,$color2 100%);
					filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='$color1', endColorstr='$color2',GradientType=1 );",
				) );
			}

			if ('radial' === $gradient_style){
				MHComposer_Core::set_style( $function_name, array(
					'selector'    => '%%order_class%%',
					'declaration' => "background: $color1;
					background-image: $image -webkit-radial-gradient(center, ellipse cover, $color1 0%,$color2 100%);
					background-image: $image radial-gradient(ellipse at center, $color1 0%,$color2 100%);
					filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='$color1', endColorstr='$color2',GradientType=1 );",
				) );
			}

		} //gradient 
		
		$output = sprintf(
			'<div%4$s class="%2$s">
				%1$s
			</div> <!-- .%3$s -->',
			$inner_content,
			esc_attr( $module_class ),
			esc_html( $function_name ),
			( '' !== $module_id ? sprintf( ' id="%1$s"', esc_attr( $module_id ) ) : '' )
		);

		return $output;
	}
}
new MHComposer_Row;

class MHComposer_Row_Inner extends MHComposer_Structure_Element {
	function init() {
		$this->name = esc_html__( 'Row', 'mh-composer' );
		$this->slug = 'mhc_row_inner';

		$this->approved_fields = array(
			'background_image',
			'background_color',
			'gradient_background',
			'gradient_style',
			'background_color_second',
			'remove_padding',
      'remove_padding_mobile',
			'top_padding',
			'bottom_padding',
			'module_id',
			'module_class',
			'admin_label',
			'background_image_size',
			'background_image_repeat',
			'background_image_position_x',
			'background_image_position_y',
			'background_image_position_x_custom',
			'background_image_position_y_custom',
      'mobile_2_pr_row',
      'mobile_reverse',
		);
		
		$this->fields_defaults = array(
			'gradient_background' 	=> array( 'off' ),
			'gradient_style' 		 => array( 'horizontal' ),
			'remove_padding' 		 => array( 'off' ),
      'remove_padding_mobile' 		 => array( 'off' ),
			'background_image_size'   	=> array( 'cover' ),
			'background_image_repeat'	=> array( 'no-repeat' ),
			'background_image_position_x'	=> array( 'center' ),
			'background_image_position_y'	=> array( 'center' ),
			'background_image_position_x_custom'	=> array( '50' ),
			'background_image_position_y_custom'	=> array( '50' ),
      'mobile_2_pr_row' => array('off'),
      'mobile_reverse' => array('off'),
		);
	}

	function get_fields() {
		$fields = array(
			'background_image' => array(
				'label'              => esc_html__( 'Background Image', 'mh-composer' ),
				'type'               => 'upload',
				'upload_button_text' => esc_attr__( 'Upload an image', 'mh-composer' ),
				'choose_text'        => esc_attr__( 'Choose a Background Image', 'mh-composer' ),
				'update_text'        => esc_attr__( 'Set As Background', 'mh-composer' ),
				'description'        => esc_html__( 'If defined, this image will be used as a background. To remove a background image, simply delete the URL from the settings field.', 'mh-composer' ),
			),
			'gradient_background' => array(
				'label'             => esc_html__( 'Gradient Background', 'mh-composer' ),
				'type'              => 'switch_button',
				'options'           => array(
					'off' => esc_html__( 'No', 'mh-composer' ),
					'on'  => esc_html__( 'Yes', 'mh-composer' ),
				),
				'affects'           => array(
					'#mhc_gradient_style',
					'#mhc_background_color_second',
				),
				'description'       => esc_html__( 'Switch on this option if you want a gradient background colour for this row.', 'mh-composer' ),
			),
			'background_color' => array(
				'label'           => esc_html__( 'Background Colour', 'mh-composer' ),
				'type'            => 'color-alpha',
				'description'     => esc_html__( 'Define a custom background colour for your component, or leave blank to use the default colour.', 'mh-composer' ),
			),
			'background_color_second' => array(
				'label'           => esc_html__( 'Gradient Colour', 'mh-composer' ),
				'type'            => 'color-alpha',
				'depends_show_if' => 'on',
				'description'     => esc_html__( 'Define a custom gradient colour for your row.', 'mh-composer' ),
			),
			'gradient_style' => array(
				'label'             => esc_html__( 'Gradient Style', 'mh-composer' ),
				'type'              => 'select',
				'options'           => array(
					'horizontal'		=> esc_html__( 'Horizontal', 'mh-composer' ),
					'vertical'		  => esc_html__( 'Vertical', 'mh-composer' ),
					'diagonal_top'	  => esc_html__( 'Diagonal Top', 'mh-composer' ),
					'diagonal_bottom'   => esc_html__( 'Diagonal Bottom', 'mh-composer' ),
					'radial'			=> esc_html__( 'Radial', 'mh-composer' ),
				),
				'depends_show_if' => 'on',
				'description'       => esc_html__( 'This controls the style of the gradient colour.', 'mh-composer' ),
			),
      'remove_padding' => array(
				'label'           => esc_html__( 'Remove Paddings', 'mh-composer' ),
				'type'            => 'switch_button',
				'options'         => array(
					'off' => esc_html__( 'No', 'mh-composer' ),
					'on'  => esc_html__( 'Yes', 'mh-composer' ),
				),
				'affects'           => array(
          '#mhc_remove_padding_mobile',
					'#mhc_top_padding',
					'#mhc_bottom_padding',
				),
				'description'       => esc_html__( 'This option will remove all top and bottom paddings for this row.', 'mh-composer' ),
			),
      'remove_padding_mobile' => array(
				'label'           => esc_html__( 'Remove Paddings on Mobile Only', 'mh-composer' ),
				'type'            => 'switch_button',
				'options'         => array(
					'off' => esc_html__( 'No', 'mh-composer' ),
					'on'  => esc_html__( 'Yes', 'mh-composer' ),
				),
			),
			'top_padding' => array(
				'label'           => esc_html__( 'Top Padding (px)', 'mh-composer' ),
				'type'            => 'range',
				'range_settings' => array(
					'min'  => '0',
					'max'  => '200',
					'step' => '1',
				),
				'depends_show_if'   => 'on',
			),
			'bottom_padding' => array(
				'label'           => esc_html__( 'Bottom Padding (px)', 'mh-composer' ),
				'type'            => 'range',
				'range_settings' => array(
					'min'  => '0',
					'max'  => '200',
					'step' => '1',
				),
				'depends_show_if'   => 'on',
			),
			'background_image_size' => array(
				'label'             => esc_html__( 'Background Image Size', 'mh-composer' ),
				'type'              => 'select',
				'options'           => array(
					'cover'		=> esc_html__( 'Cover', 'mh-composer' ),
					'contain'	=> esc_html__( 'Contain', 'mh-composer' ),
					'auto'		=> esc_html__( 'Auto', 'mh-composer' ),
				),
			),
			'background_image_repeat' => array(
				'label'             => esc_html__( 'Background Image Repeat', 'mh-composer' ),
				'type'              => 'select',
				'options'           => array(
					'no-repeat'	=> esc_html__( 'No repeat', 'mh-composer' ),
					'repeat'	=> esc_html__( 'Repeat', 'mh-composer' ),
				),
			),
			'background_image_position_x' => array(
				'label'             => esc_html__( 'Background Image Position Horizontally', 'mh-composer' ),
				'type'              => 'select',
				'options'           => array(
					'center'	=> esc_html__( 'Centre', 'mh-composer' ),
					'right'		=> esc_html__( 'Right', 'mh-composer' ),
					'left'		=> esc_html__( 'Left', 'mh-composer' ),
					'custom'	=> esc_html__( 'Custom', 'mh-composer' ),
				),
				'affects'           => array(
					'#mhc_background_image_position_x_custom',
				),
				
			),
			'background_image_position_x_custom' => array(
				'label'           => esc_html__( 'Background Image Horizontal Position', 'mh-composer' ),
				'type'            => 'range',
				'range_settings' => array(
					'min'  => '0',
					'max'  => '100',
					'step' => '1',
				),
				'depends_show_if'   => 'custom',
			),
			'background_image_position_y' => array(
				'label'             => esc_html__( 'Background Image Position Vertically', 'mh-composer' ),
				'type'              => 'select',
				'options'           => array(
					'center'	=> esc_html__( 'Centre', 'mh-composer' ),
					'top'		=> esc_html__( 'Top', 'mh-composer' ),
					'bottom'	=> esc_html__( 'Bottom', 'mh-composer' ),
					'custom'	=> esc_html__( 'Custom', 'mh-composer' ),
				),
				'affects'           => array(
					'#mhc_background_image_position_y_custom',
				),
			),
			'background_image_position_y_custom' => array(
				'label'           => esc_html__( 'Background Image Vertical Position', 'mh-composer' ),
				'type'            => 'range',
				'range_settings' => array(
					'min'  => '0',
					'max'  => '100',
					'step' => '1',
				),
				'depends_show_if'   => 'custom',
			),
      'disabled_on' => array(
				'label'           => esc_html__( 'Hide on', 'mh-composer' ),
				'type'            => 'multiple_checkboxes',
				'options'         => array(
					'phone'   => esc_html__( 'Mobile', 'mh-composer' ),
					'tablet'  => esc_html__( 'Tablet', 'mh-composer' ),
					'desktop' => esc_html__( 'Desktop', 'mh-composer' ),
				),
				'additional_att'  => 'disable_on',
				'description'     => esc_html__( 'This will hide the component on selected devices.', 'mh-composer' ),
				'tab_slug'        => 'advanced',
			),
      'mobile_2_pr_row' => array(
				'label'             => esc_html__( '2 Columns on Mobile', 'mh-composer' ),
				'type'              => 'switch_button',
				'options'           => array(
					'off' => esc_html__( 'No', 'mh-composer' ),
					'on'  => esc_html__( 'Yes', 'mh-composer' ),
				),
        'tab_slug'        => 'advanced',
        'affects' => array(
          '#mhc_mobile_reverse',
        ),
			),
      'mobile_reverse' => array(
				'label'             => esc_html__( 'Reverse Columns on Mobile', 'mh-composer' ),
				'type'              => 'switch_button',
				'options'           => array(
					'off' => esc_html__( 'No', 'mh-composer' ),
					'on'  => esc_html__( 'Yes', 'mh-composer' ),
				),
        'tab_slug'        => 'advanced',
        'depends_show_if' => 'off',
			),
			'admin_label' => array(
				'label'       => esc_html__( 'Label', 'mh-composer' ),
				'type'        => 'text',
				'description' => esc_html__( 'This will change the label of the row in the composer for easy identification when collapsed.', 'mh-composer' ),
                'tab_slug'        => 'advanced',
			),
			'module_id' => array(
				'label'             => esc_html__( '{CSS ID}', 'mh-composer' ),
				'type'              => 'text',
				'description'       => esc_html__( 'Enter an optional CSS ID. An ID can be used to create custom CSS styling, or to create links to particular sections of your page.', 'mh-composer' ),
				'tab_slug'          => 'advanced',
			),
			'module_class' => array(
				'label'             => esc_html__( '{CSS Class}', 'mh-composer' ),
				'type'              => 'text',
				'description'       => esc_html__( 'Enter optional CSS classes. A CSS class can be used to create custom CSS styling. You can add multiple classes, separated with a space.', 'mh-composer' ),
				'tab_slug'          => 'advanced',
			),
		);

		return $fields;
	}

	function shortcode_callback( $atts, $content, $function_name ) {
		$module_id					= $this->shortcode_atts['module_id'];
		$module_class				= $this->shortcode_atts['module_class'];
		$shared_module				= $this->shortcode_atts['shared_module'];
		$background_image			= $this->shortcode_atts['background_image'];
		$background_color			= $this->shortcode_atts['background_color'];
		$gradient_background		= $this->shortcode_atts['gradient_background'];
		$background_color_second	= $this->shortcode_atts['background_color_second'];
		$gradient_style				= $this->shortcode_atts['gradient_style'];
		$remove_padding				= $this->shortcode_atts['remove_padding'];
    $remove_padding_mobile = $this->shortcode_atts['remove_padding_mobile'];
		$top_padding				= $this->shortcode_atts['top_padding'];
		$bottom_padding				= $this->shortcode_atts['bottom_padding'];
		$background_image_size		= $this->shortcode_atts['background_image_size'];
		$background_image_repeat	= $this->shortcode_atts['background_image_repeat'];
		$background_image_position_x	= $this->shortcode_atts['background_image_position_x'];
		$background_image_position_y	= $this->shortcode_atts['background_image_position_y'];
		$background_image_position_x_custom	= $this->shortcode_atts['background_image_position_x_custom'];
		$background_image_position_y_custom	= $this->shortcode_atts['background_image_position_y_custom'];
    $mobile_2_pr_row = $this->shortcode_atts['mobile_2_pr_row'];
    $mobile_reverse = $this->shortcode_atts['mobile_reverse'];

		if ( '' !== $shared_module ) {
			$shared_content = mhc_load_shared_module( $shared_module, $function_name );

			if ( '' !== $shared_content ) {
				return do_shortcode( $shared_content );
			}
		}

		$module_class .= ' mhc_row_inner';

		$module_class = MHComposer_Core::add_module_order_class( $module_class, $function_name );

		$inner_content = do_shortcode( mhc_fix_shortcodes( $content ) );
		$module_class .= '' == trim( $inner_content ) ? ' mhc_row_empty' : '';
    $module_class .= 'off' !== $mobile_2_pr_row ? ' mhc_row_2pr' : '';
    $module_class .= 'off' !== $mobile_reverse && 'off' === $mobile_2_pr_row ? ' mhc_mobile_reverse' : '';
		
		if ('off' !== $remove_padding){
			MHComposer_Core::set_style( $function_name, array(
			'selector'    => '%%order_class%%',
			'declaration' => sprintf('padding-top:%1$s !important; padding-bottom:%2$s !important;',
			'' !== $top_padding ? esc_html( mh_composer_process_range_value( $top_padding )) : '0',
			'' !== $bottom_padding ? esc_html( mh_composer_process_range_value( $bottom_padding )) : '0'
			),
      'media_query' => 'off' !== $remove_padding_mobile ? MHComposer_Core::get_media_query( 'max_width_980' ) : 'general'
			) );
		}
		//background image
		if ( '' !== $background_image ) {
			MHComposer_Core::set_style( $function_name, array(
				'selector'    => '%%order_class%%',
				'declaration' => sprintf(
					'background-image:url(%s);',
					esc_url( $background_image )
				),
			) );
			//background image options
			if ('center' !== $background_image_position_x || 'center' !== $background_image_position_y || 'cover' !== $background_image_size || 'no-repeat' !== $background_image_repeat) {
				MHComposer_Core::set_style( $function_name, array(
					'selector'    => '%%order_class%%',
					'declaration' => sprintf(
						'%s%s%s',
						 sprintf('background-position:%1$s %2$s;',
              'custom' !== $background_image_position_x ? esc_html( $background_image_position_x ) : esc_html( $background_image_position_x_custom . '%' ),
              'custom' !== $background_image_position_y ? esc_html( $background_image_position_y ) : esc_html( $background_image_position_y_custom . '%' )
              ),
						'no-repeat' !== $background_image_repeat ? sprintf('background-repeat:%s;', esc_html( $background_image_repeat ) ) : '',
						'cover' !== $background_image_size ? sprintf('background-size:%s;', esc_html( $background_image_size ) ) : ''
					),
				) );
			}
		}
		//background colour
		if ( '' !== $background_color && 'off' === $gradient_background ) {
			MHComposer_Core::set_style( $function_name, array(
				'selector'    => '%%order_class%%',
				'declaration' => sprintf(
					'background-color:%s;',
					esc_html( $background_color )
				),
			) );
		//gradient colour
		}elseif ( 'off' !== $gradient_background  && '' !== $background_color && '' !== $background_color_second) {
			$color1 = esc_html( $background_color );
			$color2 = esc_html( $background_color_second );
			$image = '' !== $background_image ? sprintf('url(%s), ', esc_url( $background_image )) : '';
			if ('horizontal' === $gradient_style){	
				MHComposer_Core::set_style( $function_name, array(
					'selector'    => '%%order_class%%',
					'declaration' => "background: $color1;
					background-image: $image -webkit-linear-gradient(left, $color1 0%,$color2 100%);
					background-image: $image linear-gradient(to right, $color1 0%,$color2 100%);
					filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='$color1', endColorstr='$color2',GradientType=1 );",
				) );
			}

			if ('vertical' === $gradient_style){
				MHComposer_Core::set_style( $function_name, array(
					'selector'    => '%%order_class%%',
					'declaration' => "background: $color1;
					background-image: $image -webkit-linear-gradient(top, $color1 0%,$color2 100%);
					background-image: $image linear-gradient(to bottom, $color1 0%,$color2 100%);
					filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='$color1', endColorstr='$color2',GradientType=0 );",
				) );
			}

			if ('diagonal_top' === $gradient_style){
				MHComposer_Core::set_style( $function_name, array(
					'selector'    => '%%order_class%%',
					'declaration' => "background: $color1;
					background-image: $image -webkit-linear-gradient(-45deg, $color1 0%,$color2 100%);
					background-image: $image linear-gradient(135deg, $color1 0%,$color2 100%);
					filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='$color1', endColorstr='$color2',GradientType=1 );",
				) );
			}

			if ('diagonal_bottom' === $gradient_style){
				MHComposer_Core::set_style( $function_name, array(
					'selector'    => '%%order_class%%',
					'declaration' => "background: $color1; 
					background-image: $image -webkit-linear-gradient(45deg, $color1 0%,$color2 100%);
					background-image: $image linear-gradient(45deg, $color1 0%,$color2 100%);
					filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='$color1', endColorstr='$color2',GradientType=1 );",
				) );
			}

			if ('radial' === $gradient_style){
				MHComposer_Core::set_style( $function_name, array(
					'selector'    => '%%order_class%%',
					'declaration' => "background: $color1;
					background-image: $image -webkit-radial-gradient(center, ellipse cover, $color1 0%,$color2 100%);
					background-image: $image radial-gradient(ellipse at center, $color1 0%,$color2 100%);
					filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='$color1', endColorstr='$color2',GradientType=1 );",
				) );
			}

		} //gradient 

		$output = sprintf(
			'<div%4$s class="%2$s">
				%1$s
			</div> <!-- .%3$s -->',
			$inner_content,
			esc_attr( $module_class ),
			esc_html( $function_name ),
			( '' !== $module_id ? sprintf( ' id="%1$s"', esc_attr( $module_id ) ) : '' )
		);

		return $output;
	}
}
new MHComposer_Row_Inner;