<?php
class MHComposer_Component_Text extends MHComposer_Component {
  function init() {
    $this->name = esc_html__( 'Text', 'mh-composer' );
    $this->slug = 'mhc_text';
    $this->main_css_selector = '%%order_class%%';

    $this->approved_fields = array(
      'background_layout',
      'text_orientation',
      'animation',
      'content_new',
      'admin_label',
      'module_id',
      'module_class',
    );

    $this->fields_defaults = array(
      'background_layout' => array( 'light' ),
      'text_orientation' => array( 'right' ),
      'animation' => array( 'off' ),
    );
  }

  function get_fields() {
    // List of available animations
    $animation_options = array(
      'off' => esc_html__( 'No Animation', 'mh-composer' ),
      'right' => esc_html__( 'From Right', 'mh-composer' ),
      'left' => esc_html__( 'From Left', 'mh-composer' ),
      'top' => esc_html__( 'From Top', 'mh-composer' ),
      'bottom' => esc_html__( 'From Bottom', 'mh-composer' ),
      'scaleup' => esc_html__( 'Scale Up', 'mh-composer' ),
      'fade_in' => esc_html__( 'Fade In', 'mh-composer' ),
      'tilt_in' => esc_html__( 'Tilt In', 'mh-composer' ),
      'blur_in' => esc_html__( 'Blur In', 'mh-composer' ),
      'blur_fwd' => esc_html__( 'Blur Forward', 'mh-composer' ),
      'blur_bck' => esc_html__( 'Blur Backward', 'mh-composer' ),
      'rotate_right' => esc_html__( 'Rotate from Right', 'mh-composer' ),
      'rotate_left' => esc_html__( 'Rotate from Left', 'mh-composer' ),
      'horizontal' => esc_html__( 'Expand Horizontal', 'mh-composer' ),
      'vertical' => esc_html__( 'Expand Vertical', 'mh-composer' ),
      'unfold_right' => esc_html__( 'Unfold from Right', 'mh-composer' ),
      'unfold_left' => esc_html__( 'Unfold from Left', 'mh-composer' ),
      'bouncein' => esc_html__( 'Bounce In', 'mh-composer' ),
      'bounceinup' => esc_html__( 'Bounce from Top', 'mh-composer' ),
      'bounceindown' => esc_html__( 'Bounce from Bottom', 'mh-composer' ),
      'bounceinright' => esc_html__( 'Bounce from Right ', 'mh-composer' ),
      'bounceinleft' => esc_html__( 'Bounce from Left', 'mh-composer' ),
      'space' => esc_html__( 'Space (Constant)', 'mh-composer' ),
      'blink' => esc_html__( 'Blink (Constant)', 'mh-composer' ),
    );

    $fields = array(
      'background_layout' => array(
        'label' => esc_html__( 'Text Colour', 'mh-composer' ),
        'type' => 'select',
        'options' => array(
          'light' => esc_html__( 'Dark', 'mh-composer' ),
          'dark' => esc_html__( 'Light', 'mh-composer' ),
        ),
        'description' => esc_html__( 'Here you can choose the value of your text. If you are working with a dark background, then your text should be set to light. If you are working with a light background, then your text should be dark.', 'mh-composer' ),
      ),
      'text_orientation' => array(
        'label' => esc_html__( 'Text Orientation', 'mh-composer' ),
        'type' => 'select',
        'options' => mh_composer_get_text_orientation_options(),
        'description' => esc_html__( 'This controls the how your text is aligned.', 'mh-composer' ),
      ),
      'animation' => array(
        'label' => esc_html__( 'Animation', 'mh-composer' ),
        'type' => 'select',
        'options' => $animation_options,
        'description' => esc_html__( 'This controls the direction of the lazy-loading animation.', 'mh-composer' ),
      ),
      'content_new' => array(
        'label' => esc_html__( 'Content', 'mh-composer' ),
        'type' => 'tiny_mce',
        'description' => esc_html__( 'Input the main text content for your component here.', 'mh-composer' ),
      ),
      'disabled_on' => array(
        'label' => esc_html__( 'Hide on', 'mh-composer' ),
        'type' => 'multiple_checkboxes',
        'options' => array(
          'phone' => esc_html__( 'Mobile', 'mh-composer' ),
          'tablet' => esc_html__( 'Tablet', 'mh-composer' ),
          'desktop' => esc_html__( 'Desktop', 'mh-composer' ),
        ),
        'additional_att' => 'disable_on',
        'description' => esc_html__( 'This will hide the component on selected devices.', 'mh-composer' ),
        'tab_slug' => 'advanced',
      ),
      'admin_label' => array(
        'label' => esc_html__( 'Label', 'mh-composer' ),
        'type' => 'text',
        'description' => esc_html__( 'This will change the label of the component in the composer for easy identification.', 'mh-composer' ),
        'tab_slug' => 'advanced',
      ),
      'module_id' => array(
        'label' => esc_html__( '{CSS ID}', 'mh-composer' ),
        'type' => 'text',
        'description' => esc_html__( 'Enter an optional CSS ID. An ID can be used to create custom CSS styling, or to create links to particular sections of your page.', 'mh-composer' ),
        'tab_slug' => 'advanced',
      ),
      'module_class' => array(
        'label' => esc_html__( '{CSS Class}', 'mh-composer' ),
        'type' => 'text',
        'description' => esc_html__( 'Enter optional CSS classes. A CSS class can be used to create custom CSS styling. You can add multiple classes, separated with a space.', 'mh-composer' ),
        'tab_slug' => 'advanced',
      ),
    );
    return $fields;
  }

  function shortcode_callback( $atts, $content, $function_name ) {
    $module_id = $this->shortcode_atts[ 'module_id' ];
    $module_class = $this->shortcode_atts[ 'module_class' ];
    $background_layout = $this->shortcode_atts[ 'background_layout' ];
    $text_orientation = $this->shortcode_atts[ 'text_orientation' ];
    $animation = $this->shortcode_atts[ 'animation' ];

    $module_class = MHComposer_Core::add_module_order_class( $module_class, $function_name );

    $this->shortcode_content = mh_composer_replace_code_content_entities( $this->shortcode_content );

    $class = " mhc_module mhc_pct mhc_bg_layout_{$background_layout} mhc_text_align_{$text_orientation}";

    $output = sprintf(
      '<div%3$s class="mhc_text mh-the-content%2$s%4$s%5$s">
				%1$s
			</div> <!-- .mhc_text -->',
      $this->shortcode_content,
      esc_attr( $class ),
      ( '' !== $module_id ? sprintf( ' id="%1$s"', esc_attr( $module_id ) ) : '' ),
      ( '' !== $module_class ? sprintf( ' %1$s', esc_attr( $module_class ) ) : '' ),
      ( 'off' !== $animation ? " mh-waypoint mhc_animation_{$animation}" : '' )
    );

    return $output;
  }
}
new MHComposer_Component_Text;