<?php
class MHComposer_Component_Poster extends MHComposer_Component {
  function init() {
    $this->name = esc_html__( 'Poster', 'mh-composer' );
    $this->slug = 'mhc_texton';
    $this->main_css_selector = '%%order_class%%.mhc_texton';

    $this->approved_fields = array(
      'module_id',
      'module_class',
      'admin_label',
      'style',
      'heading',
      'sub_heading',
      'src',
      'alt',
      'title_text',
      'animation',
      'text_color',
      'text_placement',
      'text_orientation',
      'text_size',
      'hoverfx',
      'url',
      'url_new_window',
      'show_in_lightbox',
      'background_color',
      'sticky',
      'text_shadow',
      'use_border',
      'border_color',
      'border_style',
      'border_width',
      'border_hover',
      'border_radius',
      'use_button',
      'button',
      'button_color',
      'button_text_color',
      'button_style',
      'wide_button',
      'max_width',
      'custom_paddings',
      'content_new',
    );
    $accent_color = mh_composer_accent_color();
    $this->fields_defaults = array(
      'style' => array( 'full' ),
      'animation' => array( 'off' ),
      'text_color' => array( '#ffffff', 'append_default' ),
      'text_placement' => array( 'right_bottom' ),
      'text_orientation' => array( 'right' ),
      'text_size' => array( 'xl' ),
      'hoverfx' => array( 'scaleup' ),
      'url_new_window' => array( 'off' ),
      'show_in_lightbox' => array( 'off' ),
      'background_color' => array( '#121212', 'append_default' ),
      'sticky' => array( 'off' ),
      'use_button' => array( 'off' ),
      'button_color' => array( $accent_color, 'append_default' ),
      'button_text_color' => array( '#ffffff', 'append_default' ),
      'button_style' => array( 'off' ),
      'wide_button' => array( 'off' ),
      'text_shadow' => array( 'off' ),
      'use_border' => array( 'off' ),
      'border_color' => array( $accent_color, 'append_default' ),
      'border_style' => array( 'solid' ),
      'border_hover' => array( 'off' ),
      'border_radius' => array( '0', 'append_default' ),
    );

    $this->custom_css_options = array(
      'texton_image' => array(
        'label' => esc_html__( 'Image', 'mh-composer' ),
        'selector' => '.mhc_texton_image',
        'description' => esc_html__( 'Use this to add Custom CSS Properties.', 'mh-composer' ),
      ),
      'texton_title' => array(
        'label' => esc_html__( 'Title', 'mh-composer' ),
        'selector' => 'h3.mhc_texton_title',
        'description' => esc_html__( 'Use this to add Custom CSS Properties.', 'mh-composer' ),
      ),
      'texton_subtitle' => array(
        'label' => esc_html__( 'Subheading Text', 'mh-composer' ),
        'selector' => 'h4.mhc_texton_subtitle',
        'description' => esc_html__( 'Use this to add Custom CSS Properties.', 'mh-composer' ),
      ),
      'texton_button' => array(
        'label' => esc_html__( 'Button', 'mh-composer' ),
        'selector' => '.texton-button',
        'description' => esc_html__( 'Use this to add Custom CSS Properties.', 'mh-composer' ),
      ),
    );
  }

  function get_fields() {
    // List of available animations
     $animation_options = array(
      'off' => esc_html__( 'No Animation', 'mh-composer' ),
      'right' => esc_html__( 'From Right', 'mh-composer' ),
      'left' => esc_html__( 'From Left', 'mh-composer' ),
      'top' => esc_html__( 'From Top', 'mh-composer' ),
      'bottom' => esc_html__( 'From Bottom', 'mh-composer' ),
      'scaleup' => esc_html__( 'Scale Up', 'mh-composer' ),
      'fade_in' => esc_html__( 'Fade In', 'mh-composer' ),
      'tilt_in' => esc_html__( 'Tilt In', 'mh-composer' ),
      'blur_in' => esc_html__( 'Blur In', 'mh-composer' ),
      'blur_fwd' => esc_html__( 'Blur Forward', 'mh-composer' ),
      'blur_bck' => esc_html__( 'Blur Backward', 'mh-composer' ),
      'rotate_right' => esc_html__( 'Rotate from Right', 'mh-composer' ),
      'rotate_left' => esc_html__( 'Rotate from Left', 'mh-composer' ),
      'horizontal' => esc_html__( 'Expand Horizontal', 'mh-composer' ),
      'vertical' => esc_html__( 'Expand Vertical', 'mh-composer' ),
      'unfold_right' => esc_html__( 'Unfold from Right', 'mh-composer' ),
      'unfold_left' => esc_html__( 'Unfold from Left', 'mh-composer' ),
      'bouncein' => esc_html__( 'Bounce In', 'mh-composer' ),
      'bounceinup' => esc_html__( 'Bounce from Top', 'mh-composer' ),
      'bounceindown' => esc_html__( 'Bounce from Bottom', 'mh-composer' ),
      'bounceinright' => esc_html__( 'Bounce from Right ', 'mh-composer' ),
      'bounceinleft' => esc_html__( 'Bounce from Left', 'mh-composer' ),
      'space' => esc_html__( 'Space (Constant)', 'mh-composer' ),
      'blink' => esc_html__( 'Blink (Constant)', 'mh-composer' ),
    );

    $fields = array(
      'style' => array(
        'label' => esc_html__( 'Style', 'mh-composer' ),
        'type' => 'select',
        'options' => array(
          'full' => esc_html__( 'Full', 'mh-composer' ),
          'contain' => esc_html__( 'Contain', 'mh-composer' ),
          'thumb' => esc_html__( 'Thumbnail', 'mh-composer' ),
        ),
        'description' => esc_html__( 'Choose the desired style.', 'mh-composer' ),
        'affects' => array(
          '#mhc_text_placement',
          '#mhc_text_orientation',
          '#mhc_src',
          '#mhc_alt',
          '#mhc_title_text',
          '#mhc_custom_paddings',
          '#mhc_max_width',
          '#mhc_hoverfx',
        ),
      ),
      'src' => array(
        'label' => esc_html__( 'Image URL', 'mh-composer' ),
        'type' => 'upload',
        'upload_button_text' => esc_attr__( 'Upload an image', 'mh-composer' ),
        'choose_text' => esc_attr__( 'Choose an Image', 'mh-composer' ),
        'update_text' => esc_attr__( 'Set As Image', 'mh-composer' ),
        'description' => esc_html__( 'Upload your desired image, or type in the URL to the image you would like to display.', 'mh-composer' ),
        'depends_show_if_not' => 'contain',
      ),
      'heading' => array(
        'label' => esc_html__( 'Title', 'mh-composer' ),
        'type' => 'text',
        'description' => esc_html__( 'Define a title to show on your poster image.', 'mh-composer' ),
      ),
      'sub_heading' => array(
        'label' => esc_html__( 'Subheading Text', 'mh-composer' ),
        'type' => 'text',
        'description' => esc_html__( 'If you would like to use a subheading, add it here.', 'mh-composer' ),
      ),
      'text_placement' => array(
        'label' => esc_html__( 'Titles Position', 'mh-composer' ),
        'type' => 'select',
        'options' => array(
          'right_bottom' => esc_html__( 'Bottom Right', 'mh-composer' ),
          'center_bottom' => esc_html__( 'Bottom Centre', 'mh-composer' ),
          'left_bottom' => esc_html__( 'Bottom Left', 'mh-composer' ),
          'right_top' => esc_html__( 'Top Right', 'mh-composer' ),
          'center_top' => esc_html__( 'Top Centre', 'mh-composer' ),
          'left_top' => esc_html__( 'Top Left', 'mh-composer' ),
          'middle' => esc_html__( 'Centre', 'mh-composer' ),
        ),
        'description' => esc_html__( 'Define the position for your titles.', 'mh-composer' ),
        'depends_show_if' => 'full',
      ),
      'text_orientation' => array(
        'label' => esc_html__( 'Text Orientation', 'mh-composer' ),
        'type' => 'select',
        'options' => mh_composer_get_text_orientation_options(),
        'description' => esc_html__( 'This controls the how your text is aligned.', 'mh-composer' ),
        'depends_show_if' => 'contain',
      ),
      'text_size' => array(
        'label' => esc_html__( 'Text Size', 'mh-composer' ),
        'type' => 'select',
        'options' => array(
          'xl' => esc_html__( 'Large', 'mh-composer' ),
          'med' => esc_html__( 'Medium', 'mh-composer' ),
          'small' => esc_html__( 'Small', 'mh-composer' ),
          'xxl' => esc_html__( 'X Large', 'mh-composer' ),
        ),
        'description' => esc_html__( 'Define the size of your titles, depends on the amount of your text and size of your image.', 'mh-composer' ),
      ),
      'text_color' => array(
        'label' => esc_html__( 'Text Colour', 'mh-composer' ),
        'type' => 'color',
        'description' => esc_html__( 'Define a custom colour for your text, or leave blank to use the default colour.', 'mh-composer' ),
      ),
      'alt' => array(
        'label' => esc_html__( 'Image Alternative Text', 'mh-composer' ),
        'type' => 'text',
        'description' => esc_html__( 'This defines the HTML ALT text. A short description of your image can be placed here.', 'mh-composer' ),
        'depends_show_if_not' => 'contain',
      ),
      'title_text' => array(
        'label' => esc_html__( 'Image Title Text', 'mh-composer' ),
        'type' => 'text',
        'description' => esc_html__( 'This defines the HTML Title text.', 'mh-composer' ),
        'depends_show_if_not' => 'contain',
      ),
      'show_in_lightbox' => array(
        'label' => esc_html__( 'Lightbox', 'mh-composer' ),
        'type' => 'switch_button',
        'options' => array(
          'off' => esc_html__( 'No', 'mh-composer' ),
          'on' => esc_html__( 'Yes', 'mh-composer' ),
        ),
        'affects' => array(
          '#mhc_url',
          '#mhc_url_new_window',
        ),
        'description' => esc_html__( 'Here you can choose whether the image should open in Lightbox. Note: if you select to open the image in Lightbox, URL options below will be ignored.', 'mh-composer' ),
      ),
      'url' => array(
        'label' => esc_html__( 'Link URL', 'mh-composer' ),
        'type' => 'text',
        'depends_show_if' => 'off',
        'description' => esc_html__( 'If you would like your image to be a link, input your destination URL here. No link will be created if this field is left blank.', 'mh-composer' ),
      ),
      'url_new_window' => array(
        'label' => esc_html__( 'URL Opens in', 'mh-composer' ),
        'type' => 'select',
        'options' => array(
          'off' => esc_html__( 'Same Window', 'mh-composer' ),
          'on' => esc_html__( 'New Tab', 'mh-composer' ),
          'popup' => esc_html__( 'Pop-Up Window', 'mh-composer' ),
        ),
        'depends_show_if' => 'off',
        'description' => esc_html__( 'Here you can choose where your link opens.', 'mh-composer' ),
      ),
      'background_color' => array(
        'label' => esc_html__( 'Background Colour', 'mh-composer' ),
        'type' => 'color',
      ),
      'text_shadow' => array(
        'label' => esc_html__( 'Text Shadow', 'mh-composer' ),
        'type' => 'switch_button',
        'options' => array(
          'off' => esc_html__( 'No', 'mh-composer' ),
          'on' => esc_html__( 'Yes', 'mh-composer' ),
        ),
      ),
      'use_border' => array(
        'label' => esc_html__( 'Use Border', 'mh-composer' ),
        'type' => 'switch_button',
        'options' => array(
          'off' => esc_html__( 'No', 'mh-composer' ),
          'on' => esc_html__( 'Yes', 'mh-composer' ),
        ),
        'affects' => array(
          '#mhc_border_color',
          '#mhc_border_style',
          '#mhc_border_width',
          '#mhc_border_hover',
        ),
      ),
      'border_color' => array(
        'label' => esc_html__( 'Border Colour', 'mh-composer' ),
        'type' => 'color-alpha',
        'depends_default' => true,
        'depends_show_if' => 'on',
      ),
      'border_width' => array(
        'label' => esc_html__( 'Border Thickness', 'mh-composer' ),
        'type' => 'range',
        'depends_show_if' => 'on',
        'default' => '5',
      ),
      'border_style' => array(
        'label' => esc_html__( 'Border Style', 'mh-composer' ),
        'type' => 'select',
        'options' => mh_composer_get_border_styles(),
        'depends_show_if' => 'on',
      ),
      'border_hover' => array(
        'label' => esc_html__( 'Show Border on Hover', 'mh-composer' ),
        'type' => 'switch_button',
        'options' => array(
          'off' => esc_html__( 'No', 'mh-composer' ),
          'on' => esc_html__( 'Yes', 'mh-composer' ),
        ),
        'depends_show_if' => 'on',
      ),
      'border_radius' => array(
        'label' => esc_html__( 'Image Radius', 'mh-composer' ),
        'type' => 'range',
      ),
      'use_button' => array(
        'label' => esc_html__( 'Use Button', 'mh-composer' ),
        'type' => 'switch_button',
        'options' => array(
          'off' => esc_html__( 'No', 'mh-composer' ),
          'on' => esc_html__( 'Yes', 'mh-composer' ),
        ),
        'affects' => array(
          '#mhc_button',
          '#mhc_button_style',
          '#mhc_wide_button',
        ),
      ),
      'button' => array(
        'label' => esc_html__( 'Button Text', 'mh-composer' ),
        'type' => 'text',
        'depends_show_if' => 'on',
      ),
      'button_style' => array(
        'label' => esc_html__( 'Button Style', 'mh-composer' ),
        'type' => 'select',
        'options' => array(
          'off' => esc_html__( 'Transparent', 'mh-composer' ),
          'on' => esc_html__( 'Solid', 'mh-composer' ),
        ),
        'affects' => array(
          '#mhc_button_color',
          '#mhc_button_text_color',
        ),
        'depends_show_if' => 'on',
      ),
      'button_color' => array(
        'label' => esc_html__( 'Button Colour', 'mh-composer' ),
        'type' => 'color-alpha',
        'depends_default' => true,
        'depends_show_if' => 'on',
      ),
      'button_text_color' => array(
        'label' => esc_html__( 'Button Text Colour', 'mh-composer' ),
        'type' => 'color-alpha',
        'depends_default' => true,
        'depends_show_if' => 'on',
      ),
      'wide_button' => array(
        'label' => esc_html__( 'Full-width Button', 'mh-composer' ),
        'type' => 'switch_button',
        'options' => array(
          'off' => esc_html__( 'No', 'mh-composer' ),
          'on' => esc_html__( 'Yes', 'mh-composer' ),
        ),
        'depends_show_if' => 'on',
      ),
      'custom_paddings' => array(
        'label' => esc_html__( 'Padding', 'mh-composer' ),
        'type' => 'range',
        'default' => '0',
        'range_settings' => array(
          'min' => '0',
          'max' => '20',
          'step' => '1',
        ),
        'validate_unit' => true,
        'depends_show_if' => 'thumb',
      ),
      'sticky' => array(
        'label' => esc_html__( 'Remove Space Below The Image', 'mh-composer' ),
        'type' => 'switch_button',
        'options' => array(
          'off' => esc_html__( 'No', 'mh-composer' ),
          'on' => esc_html__( 'Yes', 'mh-composer' ),
        ),
      ),
      'max_width' => array(
        'label' => esc_html__( 'Image Width', 'mh-composer' ),
        'type' => 'text',
        'validate_unit' => true,
        'depends_show_if' => 'thumb',
        'description' => esc_html__( 'For best result keep it small.', 'mh-composer' ),
      ),
      'animation' => array(
        'label' => esc_html__( 'Animation', 'mh-composer' ),
        'type' => 'select',
        'options' => $animation_options,
        'description' => esc_html__( 'This controls the direction of the lazy-loading animation.', 'mh-composer' ),
      ),
      'hoverfx' => array(
        'label' => esc_html__( 'Mouse Effect', 'mh-composer' ),
        'type' => 'select',
        'options' => array(
          'scaleup' => esc_html__( 'Scale Up', 'mh-composer' ),
          'shine' => esc_html__( 'Shine', 'mh-composer' ),
          'rotate' => esc_html__( 'Rotate', 'mh-composer' ),
          'color' => esc_html__( 'Background Colour', 'mh-composer' ),
          'reverse' => esc_html__( 'Reverse Overlay Colour', 'mh-composer' ),
          'flash' => esc_html__( 'Flash Background Colour', 'mh-composer' ),
          'reveal' => esc_html__( 'Reveal Text', 'mh-composer' ),
          'none' => esc_html__( 'No Effect', 'mh-composer' ),
        ),
        'description' => esc_html__( 'This controls the effect when hovering on your poster.', 'mh-composer' ),
        'depends_show_if' => 'full',
      ),
      'content_new' => array(
        'label' => esc_html__( 'Content', 'mh-composer' ),
        'type' => 'tiny_mce',
        'description' => esc_html__( 'Input the main text content for your component here.', 'mh-composer' ),
      ),
      'disabled_on' => array(
        'label' => esc_html__( 'Hide on', 'mh-composer' ),
        'type' => 'multiple_checkboxes',
        'options' => array(
          'phone' => esc_html__( 'Mobile', 'mh-composer' ),
          'tablet' => esc_html__( 'Tablet', 'mh-composer' ),
          'desktop' => esc_html__( 'Desktop', 'mh-composer' ),
        ),
        'additional_att' => 'disable_on',
        'description' => esc_html__( 'This will hide the component on selected devices.', 'mh-composer' ),
        'tab_slug' => 'advanced',
      ),
      'admin_label' => array(
        'label' => esc_html__( 'Label', 'mh-composer' ),
        'type' => 'text',
        'description' => esc_html__( 'This will change the label of the component in the composer for easy identification.', 'mh-composer' ),
        'tab_slug' => 'advanced',
      ),
      'module_id' => array(
        'label' => esc_html__( '{CSS ID}', 'mh-composer' ),
        'type' => 'text',
        'description' => esc_html__( 'Enter an optional CSS ID. An ID can be used to create custom CSS styling, or to create links to particular sections of your page.', 'mh-composer' ),
        'tab_slug' => 'advanced',
      ),
      'module_class' => array(
        'label' => esc_html__( '{CSS Class}', 'mh-composer' ),
        'type' => 'text',
        'description' => esc_html__( 'Enter optional CSS classes. A CSS class can be used to create custom CSS styling. You can add multiple classes, separated with a space.', 'mh-composer' ),
        'tab_slug' => 'advanced',
      ),
    );
    return $fields;
  }

  function shortcode_callback( $atts, $content, $function_name ) {
    $module_id = $this->shortcode_atts[ 'module_id' ];
    $module_class = $this->shortcode_atts[ 'module_class' ];
    $style = $this->shortcode_atts[ 'style' ];
    $heading = $this->shortcode_atts[ 'heading' ];
    $sub_heading = $this->shortcode_atts[ 'sub_heading' ];
    $src = $this->shortcode_atts[ 'src' ];
    $alt = $this->shortcode_atts[ 'alt' ];
    $title_text = $this->shortcode_atts[ 'title_text' ];
    $animation = $this->shortcode_atts[ 'animation' ];
    $text_color = $this->shortcode_atts[ 'text_color' ];
    $text_placement = $this->shortcode_atts[ 'text_placement' ];
    $text_orientation = $this->shortcode_atts[ 'text_orientation' ];
    $text_size = $this->shortcode_atts[ 'text_size' ];
    $hoverfx = $this->shortcode_atts[ 'hoverfx' ];
    $url = $this->shortcode_atts[ 'url' ];
    $url_new_window = $this->shortcode_atts[ 'url_new_window' ];
    $show_in_lightbox = $this->shortcode_atts[ 'show_in_lightbox' ];
    $background_color = $this->shortcode_atts[ 'background_color' ];
    $sticky = $this->shortcode_atts[ 'sticky' ];
    $module_id = $this->shortcode_atts[ 'module_id' ];
    $module_class = $this->shortcode_atts[ 'module_class' ];
    $text_shadow = $this->shortcode_atts[ 'text_shadow' ];
    $use_button = $this->shortcode_atts[ 'use_button' ];
    $button = $this->shortcode_atts[ 'button' ];
    $button_color = $this->shortcode_atts[ 'button_color' ];
    $button_text_color = $this->shortcode_atts[ 'button_text_color' ];
    $button_style = $this->shortcode_atts[ 'button_style' ];
    $wide_button = $this->shortcode_atts[ 'wide_button' ];
    $use_border = $this->shortcode_atts[ 'use_border' ];
    $border_color = $this->shortcode_atts[ 'border_color' ];
    $border_style = $this->shortcode_atts[ 'border_style' ];
    $border_width = $this->shortcode_atts[ 'border_width' ];
    $border_hover = $this->shortcode_atts[ 'border_hover' ];
    $border_radius = $this->shortcode_atts[ 'border_radius' ];
    $custom_paddings = $this->shortcode_atts[ 'custom_paddings' ];
    $max_width = $this->shortcode_atts[ 'max_width' ];

    $module_class = MHComposer_Core::add_module_order_class( $module_class, $function_name );

    $content = $this->shortcode_content;

    if ( '' !== $text_color ) {
      MHComposer_Core::set_style( $function_name, array(
        'selector' => sprintf( '%%order_class%%%1$s',
          ( 'thumb' === $style ? '.mhc_thumb_box .mhc_thumb_box_heading' : '.mhc_texton .mhc_texton_heading' )
        ),
        'declaration' => sprintf(
          'color: %1$s;',
          esc_html( $text_color )
        ),
      ) );
    }

    if ( 'off' !== $use_button && '' !== $button && 'on' === $button_style ) {
      MHComposer_Core::set_style( $function_name, array(
        'selector' => sprintf( '%%order_class%%%1$s .texton-button',
          ( 'thumb' === $style ? '.mhc_thumb_box' : '.mhc_texton' )
        ),
        'declaration' => sprintf(
          'background-color: %1$s; border-color:%1$s; color:%2$s;',
          esc_attr( $button_color ),
          esc_attr( $button_text_color )
        ),
      ) );
    }

    if ( '' !== $background_color ) {
      MHComposer_Core::set_style( $function_name, array(
        'selector' => sprintf( '%%order_class%%%1$s',
          ( 'thumb' === $style ? '.mhc_thumb_box' : '.mhc_texton' )
        ),
        'declaration' => sprintf(
          'background-color: %1$s;',
          esc_html( $background_color )
        ),
      ) );
    }

    if ( 'thumb' === $style && '' !== $max_width ) {
      MHComposer_Core::set_style( $function_name, array(
        'selector' => sprintf( '%%order_class%%%1$s',
          '' !== $url ? ' .mhc_thumb_box_grid' : '.mhc_thumb_box_grid'
        ),
        'declaration' => sprintf(
          'grid-template-columns: %1$s 1fr;',
          esc_html( $max_width )
        ),
      ) );
    }
   // $css = '';
    if ( 'on' === $use_border ) {

      MHComposer_Core::set_style( $function_name, array(
        'selector' => sprintf( '%%order_class%%%1$s',
          ( 'thumb' === $style ? '.mhc_thumb_box' : ' .mhc_texton_border' )
        ),
        'declaration' => sprintf( ' border-color:%1$s; border-style:%2$s;',
          esc_attr( $border_color ),
          ( 'solid' !== $border_style ? esc_attr( $border_style ) : 'solid' )
        )
      ) );

     // $css .= sprintf( ' border-width: %1$spx;',
      //   ( '5' !== $border_width ? esc_attr( $border_width ) : '5' )
      // );
      if ( 'thumb' === $style ) {
        MHComposer_Core::set_style( $function_name, array(
          'selector' => sprintf( '%%order_class%%.mhc_thumb_box%1$s',
            'on' === $border_hover ? ':hover' : ''
          ),
          'declaration' => sprintf( ' border-width: %1$spx;',
            ( '5' !== $border_width ? esc_attr( $border_width ) : '5' )
          )
        ) );
      } else {
        MHComposer_Core::set_style( $function_name, array(
          'selector' => sprintf( '%%order_class%%.mhc_texton%1$s .mhc_texton_border',
            'on' === $border_hover ? ':hover' : ''
          ),
          'declaration' => sprintf( ' border-width: %1$spx;',
            ( '5' !== $border_width ? esc_attr( $border_width ) : '5' )
          )
        ) );
      }
    }

    if ( '' !== $border_radius ) {
      MHComposer_Core::set_style( $function_name, array(
        'selector' => sprintf( '%%order_class%%%1$s',
          ( 'thumb' === $style ? '.mhc_thumb_box' : ' .mhc_texton_border' )
        ),
        'declaration' => sprintf(
          '-webkit-border-radius: %1$s; border-radius: %1$s;',
          esc_html( mh_composer_process_range_value( $border_radius ) )
        ),
      ) );
    }
    if ( 'thumb' === $style && '0px' !== $custom_paddings && '' !== $custom_paddings ) {
      MHComposer_Core::set_style( $function_name, array(
        'selector' => '%%order_class%%.mhc_thumb_box',
        'declaration' => sprintf(
          'padding: %1$s;',
          esc_html( $custom_paddings )
        ),
      ) );
    }

    $url_output = $heading_output = '';
    if ( 'on' === $show_in_lightbox ) {
      $url_output = sprintf( 'href="%1$s" class="mhc_lightbox_image%3$s" title="%2$s"',
        esc_url( $src ),
        esc_attr( $alt ),
        ( 'thumb' === $style ? ' mhc_thumb_box_grid' : '' )
      );
    } else if ( '' !== $url ) {
      $url_output = sprintf( 'href="%1$s"%4$s%2$s%3$s',
        esc_url( $url ),
        ( 'on' === $url_new_window ? ' target="_blank"' : '' ),
        ( 'popup' === $url_new_window ? ' data-lity' : '' ),
        ( 'thumb' === $style ? ' class="mhc_thumb_box_grid" ' : '' )
      );
    }

    if ( '' !== $heading || '' !== $sub_heading || '' !== $content || '' !== $button ) {
      $heading_output = sprintf(
        '<div class="%8$s%3$s%4$s%5$s">
			%1$s
			%2$s
			%6$s
			%7$s
			</div>',
        ( '' !== $sub_heading ? sprintf( '<h4 class="mhc_texton_subtitle mhc_texton_child">%1$s</h4>', esc_attr( $sub_heading ) ) : '' ),
        ( '' !== $heading ? sprintf( '<h3 class="mhc_texton_title mhc_texton_child">%1$s</h3>', esc_attr( $heading ) ) : '' ),
        ( 'on' === $text_shadow ? esc_attr( ' mhc_texton_shadow' ) : '' ),
        esc_attr( " mhc_texton_place_{$text_placement}" ),
        esc_attr( " mhc_texton_size_{$text_size}" ),
        $content,
        ( 'off' !== $use_button && '' !== $button ? sprintf( '<div class="texton-button mhc_promo_button%2$s%3$s">%1$s</div>',
          esc_attr( $button ),
          ( 'on' === $button_style ?
            sprintf( ' mhc_solidify' ) :
            ' mhc_transify'
          ),
          ( 'off' !== $wide_button ? ' mhc_button_fullwidth' : '' )
        ) : '' ),
        'thumb' !== $style ? 'mhc_texton_heading ' : 'mhc_thumb_box_heading '
      );
    }
    $append_style = '';
    if ( '' !== $src && 'contain' === $style )
      $append_style .= sprintf( ' style="background-image:url(%s);"',
        esc_url( $src )
      );


    $class = " mhc_animation_{$animation} mhc_texton_style_{$style}";

    if ( 'contain' === $style ) {
      $class .= " mhc_text_align_{$text_orientation}";
    } elseif ( 'full' === $style ) {
      $class .= " mhc_fx_{$hoverfx}";
    }

    if ( 'thumb' === $style && '' === $url ) {
      $class .= " mhc_thumb_box_grid";
    }
    $image_attachment_class = mh_get_image_attachment_class( $this->shortcode_atts, 'src' );
    
    $output = sprintf(
      '<div%1$s class="%12$s mh-waypoint%2$s%3$s%4$s%9$s"%11$s>
		%5$s
    %10$s
		%7$s
    %8$s
		%6$s
		</div>',
      ( '' !== $module_id ? sprintf( ' id="%1$s"', esc_attr( $module_id ) ) : '' ),
      ( '' !== $module_class ? sprintf( ' %1$s', esc_attr( $module_class ) ) : '' ),
      ( 'on' === $sticky ? esc_attr( ' mhc_image_sticky' ) : '' ),
      esc_attr( $class ),
      ( '' !== $url_output ? sprintf( '<a %1$s>', $url_output ) : '' ),
      ( '' !== $url_output ? sprintf( '</a>' ) : '' ),
      ( '' !== $heading_output ? $heading_output : '' ),
      'on' === $use_border && 'thumb' !== $style ? '<div class="mhc_texton_border"></div>' : '',
      ( 'on' === $use_border ? sprintf( '%1$s',
        'on' === $border_hover ? ' mhc_textone_has_border_hover' : ' mhc_textone_has_border'
      ) : '' ),
      ( 'contain' !== $style ? sprintf( '<img class="mhc_texton_image%4$s" src="%1$s" alt="%2$s"%3$s />',
        esc_url( $src ),
        esc_attr( $alt ),
        ( '' !== $title_text ? sprintf( ' title="%1$s"', esc_attr( $title_text ) ) : '' ),
       ( !empty( $image_attachment_class ) ? ' ' . esc_attr( $image_attachment_class )  : '')                            
      ) : '' ),
      $append_style,
      'thumb' !== $style ? 'mhc_texton' : 'mhc_thumb_box'
    );

    return $output;

  }
}
new MHComposer_Component_Poster;