<?php
/*
Plugin Name: Mharty - Page Composer
Plugin URI: http://mharty.com/
Description: Allows you to compose pages in a beautiful way.
Version: 6.8.0
Author: mharty.com
Author URI: http://mharty.com/
Text Domain: mh-composer
Domain Path: /lang/
*/

if ( !defined( 'ABSPATH' ) ) {
  exit;
}

define( 'MHARTY_COMPOSER', true );
define( 'MH_COMPOSER_PLUGIN_DIR', trailingslashit( plugin_dir_path( __FILE__ ) ) );
define( 'MH_COMPOSER_PLUGIN_URI', plugins_url( '', __FILE__ ) );

//check for WP 5
if ( !function_exists( 'mhc_is_wp_5' ) ):
  function mhc_is_wp_5() {
    if ( version_compare( $GLOBALS[ 'wp_version' ], '5.0-beta', '>' ) ) {
      return true;
    }
    return false;
  }
endif;
if ( !class_exists( 'MHComposer', false ) ) {
  class MHComposer {
    private static $instance;

    function __construct() {
      //Only one activated instance of this cass
      if ( isset( self::$instance ) ) {
        wp_die( sprintf( '%s is a singleton class and you cannot create a second instance.',
          get_class( $this ) ) );
      }
      if ( !( defined( 'MHARTY_THEME' ) && MHARTY_THEME ) || !class_exists( 'MH_Installer', false ) ) {
        
        //show install theme notice.
        if (is_admin()) {
            require_once( MH_COMPOSER_PLUGIN_DIR . 'includes/notice.php');
        }
        return; // Disable the plugin if current theme is not Mharty, and not the the new version.
        
      }

      $this->load_textdomain();
      $this->setup_mh_composer();

      add_filter( 'body_class', array( $this, 'add_body_class' ) );
    }

    /**
     * Body Classes
     */
    function add_body_class( $classes ) {
      $classes[] = 'mh_composer';

      if ( function_exists( 'mh_composer_is_active' ) ):
        if ( ( is_page() || is_singular( 'post' ) || is_singular( 'project' ) ||  is_singular( 'product' ) ) && mh_composer_is_active( get_the_ID() ) )$classes[] = 'mhc_is_active';
        //add side nav class if used
      if ( ( is_page() || is_singular( 'post' ) || is_singular( 'project' ) ||  is_singular( 'product' ) ) && 'on' == get_post_meta( get_the_ID(), '_mhc_side_nav', true ) && mh_composer_is_active( get_the_ID() ) )$classes[] = 'mhc_side_nav_page';

      endif;

      return $classes;
    }

    /**
     * Setup
     */
    function setup_mh_composer() {
      define( 'MH_COMPOSER_VER', '6.8.0' ); //reminder: this must be chnaged in app.js
      define( 'MH_COMPOSER_DIR', MH_COMPOSER_PLUGIN_DIR . 'app/' );
      define( 'MH_COMPOSER_URI', trailingslashit( plugins_url( '', __FILE__ ) ) . 'app' );
      define( 'MH_COMPOSER_LAYOUT_POST_TYPE', 'mhc_layout' );

      require MH_COMPOSER_PLUGIN_DIR . 'includes/functions.php';
      require MH_COMPOSER_PLUGIN_DIR . 'includes/layouts.php';
      require MH_COMPOSER_PLUGIN_DIR . 'includes/sections.php';
      require MH_COMPOSER_DIR . 'app.php';
      if ( is_admin() ) {
        require_once( MH_COMPOSER_DIR . 'admin/load.php' );
      }
      
      require_once( MH_COMPOSER_PLUGIN_DIR . 'includes/plugins/block-editor.php' );      
      
      mhc_register_posttypes();

      add_action( 'mh_add_to_mharty_menu', array( $this, 'add_mh_composer_menu' ) );
    }

    /**
     * Menu
     * 		- Add My Layouts
     * 	 	- Add Composer Settings
     */
    function add_mh_composer_menu() {
      global $mhc_timeout_recovery_page, $mhc_cache_recovery_page;
      add_submenu_page( 'mh_start', esc_html__( 'Composer Settings', 'mh-composer' ), esc_html__( 'Composer Settings', 'mh-composer' ), 'manage_options', 'mhc_roles_manager', 'mhc_display_roles_manager' );
      if ( mhc_permitted( 'mharty_vault' ) ) {
        add_submenu_page( 'mh_start', esc_html__( 'My Layouts', 'mh-composer' ), esc_html__( 'My Layouts', 'mh-composer' ), 'manage_options', 'edit.php?post_type=mhc_layout' );
      }

      $mhc_timeout_recovery_page = add_submenu_page( null, esc_html__( 'Recovery (Timeout)', 'mh-composer' ), esc_html__( 'Recovery (Timeout)', 'mh-composer' ), 'manage_options', 'mhc_timeout_recovery', 'mhc_display_timeout_recovery_page' );
      $mhc_cache_recovery_page = add_submenu_page( null, esc_html__( 'Recovery (Cache)', 'mh-composer' ), esc_html__( 'Recovery (Cache)', 'mh-composer' ), 'manage_options', 'mhc_cache_recovery', 'mhc_display_cache_recovery_page' );
    }

    /**
     * Internationalization
     * 		- WP_LANG_DIR/mh-composer/mh-composer-$locale.mo
     * 	 	- mh-composer/lang/mh-composer-$locale.mo
     */
    function load_textdomain() {
      $locale = apply_filters( 'plugin_locale', get_locale(), 'mh-composer' );
      load_textdomain( 'mh-composer', WP_LANG_DIR . '/mh-composer/mh-composer-' . $locale . '.mo' );
      load_plugin_textdomain( 'mh-composer', false, plugin_basename( dirname( __FILE__ ) ) . "/lang" );
    }
    
  }
}

/**
 * Init MHComposer when WordPress Initialises.
 */
function mh_composer_init_plugin() {
  new MHComposer();
}
add_action( 'init', 'mh_composer_init_plugin' );

/**
 * Activation hook
 */
function mh_composer_activate() {

  update_option( 'mh_composer_activated', true );

}
register_activation_hook( __FILE__, 'mh_composer_activate' );


function mh_composer_load_plugin() {

  if ( is_admin() && get_option( 'mh_composer_activated' ) ) {

    delete_option( 'mh_composer_activated' );
    
     //Check theme exist and it is the new version
    if ( class_exists( 'MH_Installer', false ) ) {
      //Redirect to start page
      wp_safe_redirect( add_query_arg( array( 'page' => 'mh_start' ), admin_url( 'admin.php' ) ) );
    }
      //Force clear MH Composer cache
    if ( function_exists( 'mh_update_option' ) ) {
      mh_update_option( 'mhc_clear_templates_cache', 'on' );
    }

  }
}
add_action( 'admin_init', 'mh_composer_load_plugin' );


/**
 * Deactivation hook
 */
function mh_composer_deactivate() {

  //Force clear MH Composer cache
  if ( function_exists( 'mh_update_option' ) ) {
    mh_update_option( 'mhc_clear_templates_cache', 'on' );
  }

}
register_deactivation_hook( __FILE__, 'mh_composer_deactivate' );