<?php
/*
Plugin Name: Mharty - Love it
Plugin URI: http://mharty.com/
Description: Add likes and sharing icons to your posts and projects.
Version: 3.3.0
Author: mharty.com
Author URI: http://mharty.com/
Text Domain: mh-loveit
Domain Path: /lang/
 */
if ( !defined( 'ABSPATH' ) ) {
  exit;
}

if ( !class_exists( 'MHLoveitClass', false ) ) {
  class MHLoveitClass {
    private static $instance;

    function __construct() {
      //Only one activated instance of this cass
      if ( isset( self::$instance ) ) {
        wp_die( sprintf( '%s is a singleton class and you cannot create a second instance.',
          get_class( $this ) ) );
      }
      if ( !( defined( 'MHARTY_THEME' ) && MHARTY_THEME ) || !class_exists( 'MH_Installer', false ) || !( defined( 'MHARTY_COMPOSER' ) && MHARTY_COMPOSER ) ) {
        
        //show install theme notice.
        if (is_admin()) {
            require_once( plugin_dir_path( __FILE__ ) . 'includes/notice.php');
        }
        
        return; // Disable the plugin if current theme is not Mharty, not the the new version, and MH Composer is not active.
      }

      $this->load_textdomain();
      $this->setup_mh_loveit();
    }

    /**
     * Setup
     */
    function setup_mh_loveit() {
      define( 'MH_LOVEIT_VER', '3.3.0' );
      define( 'MH_LOVEIT_URL', plugin_dir_url( __FILE__ ) );
      define( 'MH_LOVEIT_DIR', plugin_dir_path( __FILE__ ) );

      require_once MH_LOVEIT_DIR . 'includes/likes.php';
      require_once MH_LOVEIT_DIR . 'includes/functions.php';
      //hook components to the composer list
      add_action( 'mh_composer_add_extra_components', 'mh_loveit_add_elements' );
    }

    /**
     * Internationalization
     * 		- WP_LANG_DIR/mh-loveit/mh-loveit-$locale.mo
     * 	 	- mh-loveit/lang/mh-loveit-$locale.mo
     */
    function load_textdomain() {
      $locale = apply_filters( 'plugin_locale', get_locale(), 'mh-loveit' );
      load_textdomain( 'mh-loveit', WP_LANG_DIR . '/mh-loveit/mh-loveit-' . $locale . '.mo' );
      load_plugin_textdomain( 'mh-loveit', false, plugin_basename( dirname( __FILE__ ) ) . "/lang" );
    }

  }
}
/**
 * Init MHLoveitClass when WordPress Initialises.
 */
function mh_loveit_init_plugin() {
  new MHLoveitClass();
}
add_action( 'init', 'mh_loveit_init_plugin' );


/**
 * Add after theme setup
 */
function mh_loveit_setup_theme() {
  //Show only if Mharty theme and MH Composer are active
  if ( ( defined( 'MHARTY_THEME' ) && MHARTY_THEME ) && class_exists( 'MHComposer', false ) ) {
    require plugin_dir_path( __FILE__ ) . 'includes/customizer.php';
  }
}
add_action( 'after_setup_theme', 'mh_loveit_setup_theme' );

/**
 * Activation hook
 */
function mh_loveit_activate() {

  update_option( 'mh_loveit_activated', true );

}
register_activation_hook( __FILE__, 'mh_loveit_activate' );


function mh_loveit_load_plugin() {

  if ( is_admin() && get_option( 'mh_loveit_activated' ) ) {

    delete_option( 'mh_loveit_activated' );
    
    //Check theme exist and it is the new version
    if ( class_exists( 'MH_Installer', false ) ) {
      //Redirect to start page
      wp_safe_redirect( add_query_arg( array( 'page' => 'mh_start' ), admin_url( 'admin.php' ) ) );
    }
      //Force clear MH Composer cache
    if ( function_exists( 'mh_update_option' ) ) {
      mh_update_option( 'mhc_clear_templates_cache', 'on' );
    }
    
  }
}
add_action( 'admin_init', 'mh_loveit_load_plugin' );


/**
 * Deactivation hook
 */
function mh_loveit_deactivate() {

  //Force clear MH Composer cache
  if ( function_exists( 'mh_update_option' ) ) {
    mh_update_option( 'mhc_clear_templates_cache', 'on' );
  }

}
register_deactivation_hook( __FILE__, 'mh_loveit_deactivate' );