<?php
/*
Plugin Name: Mharty - More Icons
Plugin URI: http://mharty.com/
Description: This extension offers more than 1200 icons to use in MH Page Composer.
Version: 2.2.0
Author: mharty.com
Author URI: http://mharty.com/
Text Domain: mh-more-icons
Domain Path: /lang/
*/
if ( !defined( 'ABSPATH' ) ) {
  exit; // Exit if accessed directly
}

if ( !class_exists( 'MHMoreIconsClass', false ) ) {
  class MHMoreIconsClass {
    private static $instance;

    function __construct() {
      //Only one activated instance of this cass
      if ( isset( self::$instance ) ) {
        wp_die( sprintf( '%s is a singleton class and you cannot create a second instance.',
          get_class( $this ) ) );
      }
      if ( !( defined( 'MHARTY_THEME' ) && MHARTY_THEME ) || !class_exists( 'MH_Installer', false ) || !( defined( 'MHARTY_COMPOSER' ) && MHARTY_COMPOSER ) ) {
        
        //show install theme notice.
        if (is_admin()) {
            require_once( plugin_dir_path( __FILE__ ) . 'includes/notice.php');
        }
        
        return; // Disable the plugin if current theme is not Mharty, not the the new version, and MH Composer is not active.
      }

      $this->load_textdomain();
      $this->setup_mh_more_icons();
    }

    /**
     * Setup
     */
    function setup_mh_more_icons() {
      define( 'MH_MORE_ICONS_VER', '2.2.0' );
      define( 'MH_MORE_ICONS_URL', plugin_dir_url( __FILE__ ) );
      define( 'MH_MORE_ICONS_DIR', plugin_dir_path( __FILE__ ) );

      require_once MH_MORE_ICONS_DIR . 'includes/functions.php';
      require_once MH_MORE_ICONS_DIR . 'includes/panel.php';
    }

    /**
     * Internationalization
     * 		- WP_LANG_DIR/mh-more-icons/mh-more-icons-$locale.mo
     * 	 	- mh-more-icons/lang/mh-more-icons-$locale.mo
     */
    function load_textdomain() {
      $locale = apply_filters( 'plugin_locale', get_locale(), 'mh-more-icons' );
      load_textdomain( 'mh-more-icons', WP_LANG_DIR . '/mh-more-icons/mh-more-icons-' . $locale . '.mo' );
      load_plugin_textdomain( 'mh-more-icons', false, plugin_basename( dirname( __FILE__ ) ) . "/lang" );
    }

  }
}

/**
 * Init MHMoreIconsClass when WordPress Initialises.
 */
function mh_more_icons_init_plugin() {
  new MHMoreIconsClass();
}
add_action( 'init', 'mh_more_icons_init_plugin' );

/**
 * Activation hook
 */
function mh_more_icons_activate() {

  update_option( 'mh_more_icons_activated', true );

}
register_activation_hook( __FILE__, 'mh_more_icons_activate' );


function mh_more_icons_load_plugin() {

  if ( is_admin() && get_option( 'mh_more_icons_activated' ) ) {

    delete_option( 'mh_more_icons_activated' );
   
    //Check theme exist and it is the new version
    if ( class_exists( 'MH_Installer', false ) ) {
      //Redirect to start page
      wp_safe_redirect( add_query_arg( array( 'page' => 'mh_start' ), admin_url( 'admin.php' ) ) );
    }
      //Force clear MH Composer cache
    if ( function_exists( 'mh_update_option' ) ) {
      mh_update_option( 'mhc_clear_templates_cache', 'on' );
    }
    
  }
}
add_action( 'admin_init', 'mh_more_icons_load_plugin' );


/**
 * Deactivation hook
 */
function mh_more_icons_deactivate() {

  //Force clear MH Composer cache
  if ( function_exists( 'mh_update_option' ) ) {
    mh_update_option( 'mhc_clear_templates_cache', 'on' );
  }

}
register_deactivation_hook( __FILE__, 'mh_more_icons_deactivate' );