<?php
/*
Plugin Name: Mharty - Shortcodes
Plugin URI: http://mharty.com/
Description: Add buttons, dividers, marker, info boxes via easy to use shortcodes.
Version: 2.4.0
Author: mharty.com
Author URI: http://mharty.com/
Text Domain: mh-shortcodes
Domain Path: /lang/
 */
if ( !defined( 'ABSPATH' ) ) {
  exit; // Exit if accessed directly
}

if ( !class_exists( 'MHShortcodesClass', false ) ) {
  class MHShortcodesClass {
    private static $instance;

    function __construct() {
      //Only one activated instance of this cass
      if ( isset( self::$instance ) ) {
        wp_die( sprintf( '%s is a singleton class and you cannot create a second instance.',
          get_class( $this ) ) );
      }
      
       if ( !( defined( 'MHARTY_THEME' ) && MHARTY_THEME ) || !class_exists( 'MH_Installer', false ) || !( defined( 'MHARTY_COMPOSER' ) && MHARTY_COMPOSER ) ) {
        
        //show install theme notice.
        if (is_admin()) {
            require_once( plugin_dir_path( __FILE__ ) . 'includes/notice.php');
        }
        
        return; // Disable the plugin if current theme is not Mharty, not the the new version, and MH Composer is not active.
      }

      $this->load_textdomain();
      $this->setup_mh_shortcodes();
    }

    /**
     * Setup
     */
    function setup_mh_shortcodes() {
      define( 'MH_SHORTCODES_VER', '2.4.0' );
      define( 'MH_SHORTCODES_URL', plugin_dir_url( __FILE__ ) );
      define( 'MH_SHORTCODES_DIR', plugin_dir_path( __FILE__ ) );

      require_once MH_SHORTCODES_DIR . 'includes/functions.php';
      require_once MH_SHORTCODES_DIR . 'includes/shortcodes.php';
    }

    /**
     * Internationalization
     * 		- WP_LANG_DIR/mh-shortcodes/mh-shortcodes-$locale.mo
     * 	 	- mh-shortcodes/lang/mh-shortcodes-$locale.mo
     */
    function load_textdomain() {
      $locale = apply_filters( 'plugin_locale', get_locale(), 'mh-shortcodes' );
      load_textdomain( 'mh-shortcodes', WP_LANG_DIR . '/mh-shortcodes/mh-shortcodes-' . $locale . '.mo' );
      load_plugin_textdomain( 'mh-shortcodes', false, plugin_basename( dirname( __FILE__ ) ) . "/lang" );
    }

  }
}
/**
 * Init MHShortcodesClass when WordPress Initialises.
 */
function mh_shortcodes_init_plugin() {
  new MHShortcodesClass();
}
add_action( 'init', 'mh_shortcodes_init_plugin' );

// Add Shortcode Generator Button
class MH_Shortcodes_Add_Shortcode_Generator_Button {

  function __construct() {
    add_action( 'init', array( & $this, 'init' ) );
  }

  function init() {
    if ( !current_user_can( 'edit_posts' ) && !current_user_can( 'edit_pages' ) ) {
      return;
    }

    if ( get_user_option( 'rich_editing' ) == 'true' ) {
      add_filter( 'mce_external_plugins', array( & $this, 'mhsc_shortcodes_plugin' ) );
      add_filter( 'mce_buttons', array( & $this, 'mhsc_shortcodes_register' ) );
    }
  }

  function mhsc_shortcodes_plugin( $plugin_array ) {
    global $pagenow;
    
    if (!class_exists( 'MH_Installer', false ))
      return;
    
    $is_edit_url = in_array( basename( $_SERVER['PHP_SELF'] ), array( 'post-new.php', 'page-new.php', 'post.php', 'page.php' ) );
    if ( ! is_admin() || ! $is_edit_url || ! current_user_can( 'edit_posts' ) || ! current_user_can( 'edit_pages' ) || mh_is_gutenberg_enabled() ) {
      return;
    }
      
    if ( in_array( $pagenow, array( 'post.php', 'post-new.php' ) ) ) {
      $plugin_array[ 'mhsc_shortcodes' ] = plugin_dir_url( __FILE__ ) . '/js/mhsc_tinymce.js';
    }
     return $plugin_array;
  }


  function mhsc_shortcodes_register( $buttons ) {
    array_push( $buttons, 'mhsc_shortcodes_button' );
    return $buttons;
  }  
  
}

$mhsc_shortcodes = new MH_Shortcodes_Add_Shortcode_Generator_Button;

//remove empty <p>
if ( !function_exists( 'mhsc_remove_p_shortcodes' ) ):
  function mhsc_remove_p_shortcodes( $content ) {

    $array = array(
      '<p>[' => '[',
      ']</p>' => ']',
      ']<br />' => ']'
    );

    $content = strtr( $content, $array );

    return $content;

  }
add_filter( 'the_content', 'mhsc_remove_p_shortcodes' );
endif;

/**
 * Activation hook
 */
function mh_shortcodes_activate() {

  update_option( 'mh_shortcodes_activated', true );

}
register_activation_hook( __FILE__, 'mh_shortcodes_activate' );

function mh_shortcodes_load_plugin() {

  if ( is_admin() && get_option( 'mh_shortcodes_activated' ) ) {

    delete_option( 'mh_shortcodes_activated' );
    
    //Check theme exist and it is the new version
    if ( class_exists( 'MH_Installer', false ) ) {
      //Redirect to start page
      wp_safe_redirect( add_query_arg( array( 'page' => 'mh_start' ), admin_url( 'admin.php' ) ) );
    }
      //Force clear MH Composer cache
    if ( function_exists( 'mh_update_option' ) ) {
      mh_update_option( 'mhc_clear_templates_cache', 'on' );
    }
    
  }
}
add_action( 'admin_init', 'mh_shortcodes_load_plugin' );


/**
 * Deactivation hook
 */
function mh_shortcodes_deactivate() {

  //Force clear MH Composer cache
  if ( function_exists( 'mh_update_option' ) ) {
    mh_update_option( 'mhc_clear_templates_cache', 'on' );
  }

}
register_deactivation_hook( __FILE__, 'mh_shortcodes_deactivate' );
